@@ -3,6 +3,7 @@
  *
  * g_atomic_*: atomic operations.
  * Copyright (C) 2003 Sebastian Wilhelmi
+ * Copyright (C) 2007 Nokia Corporation
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,11 +20,15 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
- 
+
 #include "config.h"
 
+#if defined (G_ATOMIC_ARM)
+#include <sched.h>
+#endif
+
 #include "glib.h"
-#include "gthreadinit.h"
+#include "gthreadprivate.h"
 #include "galias.h"
 
 #if defined (__GNUC__)
@@ -276,6 +281,7 @@ g_atomic_int_exchange_and_add (volatile gint *atomic,
 			       gint           val)
 {
   gint result, temp;
+#if ASM_NUMERIC_LABELS
   __asm__ __volatile__ ("1:       lwarx   %0,0,%3\n"
 			"         add     %1,%0,%4\n"
 			"         stwcx.  %1,0,%3\n"
@@ -283,6 +289,15 @@ g_atomic_int_exchange_and_add (volatile gint *atomic,
 			: "=&b" (result), "=&r" (temp), "=m" (*atomic)
 			: "b" (atomic), "r" (val), "m" (*atomic)
 			: "cr0", "memory");
+#else
+  __asm__ __volatile__ (".Lieaa%=:       lwarx   %0,0,%3\n"
+			"         add     %1,%0,%4\n"
+			"         stwcx.  %1,0,%3\n"
+			"         bne-    .Lieaa%="
+			: "=&b" (result), "=&r" (temp), "=m" (*atomic)
+			: "b" (atomic), "r" (val), "m" (*atomic)
+			: "cr0", "memory");
+#endif
   return result;
 }
  
@@ -292,6 +307,7 @@ g_atomic_int_add (volatile gint *atomic,
 		  gint           val)
 {
   gint result, temp;  
+#if ASM_NUMERIC_LABELS
   __asm__ __volatile__ ("1:       lwarx   %0,0,%3\n"
 			"         add     %1,%0,%4\n"
 			"         stwcx.  %1,0,%3\n"
@@ -299,6 +315,15 @@ g_atomic_int_add (volatile gint *atomic,
 			: "=&b" (result), "=&r" (temp), "=m" (*atomic)
 			: "b" (atomic), "r" (val), "m" (*atomic)
 			: "cr0", "memory");
+#else
+  __asm__ __volatile__ (".Lia%=:       lwarx   %0,0,%3\n"
+			"         add     %1,%0,%4\n"
+			"         stwcx.  %1,0,%3\n"
+			"         bne-    .Lia%="
+			: "=&b" (result), "=&r" (temp), "=m" (*atomic)
+			: "b" (atomic), "r" (val), "m" (*atomic)
+			: "cr0", "memory");
+#endif
 }
 #   else /* !__OPTIMIZE__ */
 gint
@@ -331,6 +356,7 @@ g_atomic_int_compare_and_exchange (volatile gint *atomic,
 				   gint           newval)
 {
   gint result;
+#if ASM_NUMERIC_LABELS
   __asm__ __volatile__ ("sync\n"
 			"1: lwarx   %0,0,%1\n"
 			"   subf.   %0,%2,%0\n"
@@ -341,6 +367,18 @@ g_atomic_int_compare_and_exchange (volatile gint *atomic,
 			: "=&r" (result)
 			: "b" (atomic), "r" (oldval), "r" (newval)
 			: "cr0", "memory"); 
+#else
+  __asm__ __volatile__ ("sync\n"
+			".L1icae%=: lwarx   %0,0,%1\n"
+			"   subf.   %0,%2,%0\n"
+			"   bne     .L2icae%=\n"
+			"   stwcx.  %3,0,%1\n"
+			"   bne-    .L1icae%=\n"
+			".L2icae%=: isync"
+			: "=&r" (result)
+			: "b" (atomic), "r" (oldval), "r" (newval)
+			: "cr0", "memory"); 
+#endif
   return result == 0;
 }
 
@@ -350,6 +388,7 @@ g_atomic_pointer_compare_and_exchange (volatile gpointer *atomic,
 				       gpointer           newval)
 {
   gpointer result;
+#if ASM_NUMERIC_LABELS
   __asm__ __volatile__ ("sync\n"
 			"1: lwarx   %0,0,%1\n"
 			"   subf.   %0,%2,%0\n"
@@ -360,6 +399,18 @@ g_atomic_pointer_compare_and_exchange (volatile gpointer *atomic,
 			: "=&r" (result)
 			: "b" (atomic), "r" (oldval), "r" (newval)
 			: "cr0", "memory"); 
+#else
+  __asm__ __volatile__ ("sync\n"
+			".L1pcae%=: lwarx   %0,0,%1\n"
+			"   subf.   %0,%2,%0\n"
+			"   bne     .L2pcae%=\n"
+			"   stwcx.  %3,0,%1\n"
+			"   bne-    .L1pcae%=\n"
+			".L2pcae%=: isync"
+			: "=&r" (result)
+			: "b" (atomic), "r" (oldval), "r" (newval)
+			: "cr0", "memory"); 
+#endif
   return result == 0;
 }
 #   elif GLIB_SIZEOF_VOID_P == 8 /* 64-bit system */
@@ -369,6 +420,7 @@ g_atomic_int_compare_and_exchange (volatile gint *atomic,
 				   gint           newval)
 {
   gpointer result;
+#if ASM_NUMERIC_LABELS
   __asm__ __volatile__ ("sync\n"
 			"1: lwarx   %0,0,%1\n"
 			"   extsw   %0,%0\n"
@@ -380,6 +432,19 @@ g_atomic_int_compare_and_exchange (volatile gint *atomic,
 			: "=&r" (result)
 			: "b" (atomic), "r" (oldval), "r" (newval)
 			: "cr0", "memory"); 
+#else
+  __asm__ __volatile__ ("sync\n"
+			".L1icae%=: lwarx   %0,0,%1\n"
+			"   extsw   %0,%0\n"
+			"   subf.   %0,%2,%0\n"
+			"   bne     .L2icae%=\n"
+			"   stwcx.  %3,0,%1\n"
+			"   bne-    .L1icae%=\n"
+			".L2icae%=: isync"
+			: "=&r" (result)
+			: "b" (atomic), "r" (oldval), "r" (newval)
+			: "cr0", "memory"); 
+#endif
   return result == 0;
 }
 
@@ -389,6 +454,7 @@ g_atomic_pointer_compare_and_exchange (volatile gpointer *atomic,
 				       gpointer           newval)
 {
   gpointer result;
+#if ASM_NUMERIC_LABELS
   __asm__ __volatile__ ("sync\n"
 			"1: ldarx   %0,0,%1\n"
 			"   subf.   %0,%2,%0\n"
@@ -399,6 +465,18 @@ g_atomic_pointer_compare_and_exchange (volatile gpointer *atomic,
 			: "=&r" (result)
 			: "b" (atomic), "r" (oldval), "r" (newval)
 			: "cr0", "memory"); 
+#else
+  __asm__ __volatile__ ("sync\n"
+			".L1pcae%=: ldarx   %0,0,%1\n"
+			"   subf.   %0,%2,%0\n"
+			"   bne     .L2pcae%=\n"
+			"   stdcx.  %3,0,%1\n"
+			"   bne-    .L1pcae%=\n"
+			".L2pcae%=: isync"
+			: "=&r" (result)
+			: "b" (atomic), "r" (oldval), "r" (newval)
+			: "cr0", "memory"); 
+#endif
   return result == 0;
 }
 #  else /* What's that */
@@ -482,7 +560,98 @@ g_atomic_pointer_compare_and_exchange (volatile gpointer *atomic,
 #  else /* What's that */
 #    error "Your system has an unsupported pointer size"
 #  endif /* GLIB_SIZEOF_VOID_P */
-# else /* !G_ATOMIC_IA64 */
+# elif defined (G_ATOMIC_ARM)
+static volatile int atomic_spin = 0;
+
+static int atomic_spin_trylock (void)
+{
+  int result;
+
+  asm volatile (
+    "swp %0, %1, [%2]\n"
+    : "=&r,&r" (result)
+    : "r,0" (1), "r,r" (&atomic_spin)
+    : "memory");
+  if (result == 0)
+    return 0;
+  else
+    return -1;
+}
+
+static void atomic_spin_lock (void)
+{
+  while (atomic_spin_trylock())
+    sched_yield();
+}
+
+static void atomic_spin_unlock (void)
+{
+  atomic_spin = 0;
+}
+
+gint
+g_atomic_int_exchange_and_add (volatile gint *atomic, 
+			       gint           val)
+{
+  gint result;
+ 
+  atomic_spin_lock();  
+  result = *atomic;
+  *atomic += val;
+  atomic_spin_unlock();
+
+  return result;
+}
+
+void
+g_atomic_int_add (volatile gint *atomic,
+		  gint           val)
+{
+  atomic_spin_lock();
+  *atomic += val;
+  atomic_spin_unlock();
+}
+
+gboolean
+g_atomic_int_compare_and_exchange (volatile gint *atomic, 
+				   gint           oldval, 
+				   gint           newval)
+{
+  gboolean result;
+
+  atomic_spin_lock();
+  if (*atomic == oldval)
+    {
+      result = TRUE;
+      *atomic = newval;
+    }
+  else
+    result = FALSE;
+  atomic_spin_unlock();
+
+  return result;
+}
+
+gboolean
+g_atomic_pointer_compare_and_exchange (volatile gpointer *atomic, 
+				       gpointer           oldval, 
+				       gpointer           newval)
+{
+  gboolean result;
+ 
+  atomic_spin_lock();
+  if (*atomic == oldval)
+    {
+      result = TRUE;
+      *atomic = newval;
+    }
+  else
+    result = FALSE;
+  atomic_spin_unlock();
+
+  return result;
+}
+# else /* !G_ATOMIC_ARM */
 #  define DEFINE_WITH_MUTEXES
 # endif /* G_ATOMIC_IA64 */
 #else /* !__GNUC__ */
@@ -495,7 +664,17 @@ g_atomic_pointer_compare_and_exchange (volatile gpointer *atomic,
 
 #ifdef DEFINE_WITH_WIN32_INTERLOCKED
 # include <windows.h>
-gint32   
+/* Following indicates that InterlockedCompareExchangePointer is
+ * declared in winbase.h (included by windows.h) and needs to be
+ * commented out if not true. It is defined iff WINVER > 0x0400,
+ * which is usually correct but can be wrong if WINVER is set before
+ * windows.h is included.
+ */
+# if WINVER > 0x0400
+#  define HAVE_INTERLOCKED_COMPARE_EXCHANGE_POINTER
+# endif
+
+gint32
 g_atomic_int_exchange_and_add (volatile gint32 *atomic,
 			       gint32           val)
 {
@@ -514,9 +693,15 @@ g_atomic_int_compare_and_exchange (volatile gint32 *atomic,
 				   gint32           oldval,
 				   gint32           newval)
 {
+#ifndef HAVE_INTERLOCKED_COMPARE_EXCHANGE_POINTER
   return (guint32) InterlockedCompareExchange ((PVOID*)atomic, 
                                                (PVOID)newval, 
                                                (PVOID)oldval) == oldval;
+#else
+  return InterlockedCompareExchange (atomic, 
+                                     newval, 
+                                     oldval) == oldval;
+#endif
 }
 
 gboolean 
@@ -524,10 +709,14 @@ g_atomic_pointer_compare_and_exchange (volatile gpointer *atomic,
 				       gpointer           oldval,
 				       gpointer           newval)
 {
-# if GLIB_SIZEOF_VOID_P != 4 /* no 32-bit system */
-#  error "InterlockedCompareExchangePointer needed"
+# ifdef HAVE_INTERLOCKED_COMPARE_EXCHANGE_POINTER
+  return InterlockedCompareExchangePointer (atomic, newval, oldval) == oldval;
 # else
+#  if GLIB_SIZEOF_VOID_P != 4 /* no 32-bit system */
+#   error "InterlockedCompareExchangePointer needed"
+#  else
    return InterlockedCompareExchange (atomic, newval, oldval) == oldval;
+#  endif
 # endif
 }
 #endif /* DEFINE_WITH_WIN32_INTERLOCKED */
